@@ -1,4 +1,4 @@
-#!/usr/bin/python3.6
+#!/usr/bin/python3.5
 """Autoconfigure a Django project from on a github URL.
 
 - downloads the repo
@@ -28,7 +28,7 @@ def main(repo_url, domain, python_version, nuke):
     if domain == 'your-username.pythonanywhere.com':
         username = getpass.getuser().lower()
         pa_domain = os.environ.get('PYTHONANYWHERE_DOMAIN', 'pythonanywhere.com')
-        domain = f'{username}.{pa_domain}'
+        domain = '{username}.{pa_domain}'.format(username=username, pa_domain=pa_domain)
 
     project = DjangoProject(domain, python_version)
     project.sanity_checks(nuke=nuke)
@@ -42,16 +42,11 @@ def main(repo_url, domain, python_version, nuke):
     project.run_collectstatic()
     project.run_migrate()
     project.webapp.reload()
-    print(snakesay(f'All done!  Your site is now live at https://{domain}'))
+    print(snakesay('All done!  Your site is now live at https://{domain}'.format(domain=domain)))
     print()
     project.start_bash()
 
 
-
-
-
-
 if __name__ == '__main__':
     arguments = docopt(__doc__)
     main(arguments['<git-repo-url>'], arguments['--domain'], arguments['--python'], nuke=arguments.get('--nuke'))
-
